:orphan:

`plasmapy.formulary.collisions.frequencies`
===========================================

.. currentmodule:: plasmapy.formulary.collisions.frequencies

.. automodapi:: plasmapy.formulary.collisions.frequencies
